Page 152 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 152

Home

    And the Lord said, Behold, the people is one, and
    they have all one language; and this they begin to do: and
    now nothing will be restrained from them, which they
    have imagined to do.

    nm 1 44

    The potential for evil in the attempt to build the
    Tower of Babel, as recorded in the eleventh chapter of
    Genesis, was not in any threat to physically "reach unto
    heaven," nor was it in the desire to establish a city. The
    danger was in a concentration of power and the
    elimination of the division of nations established by

    me nm

    A division of nations is of paramount importance
    because it has served to control the spread of evil
    throughout the earth. This is substantiated by Bible
    history in that the concept of nations was not established
    until after the universal flood of Noah's time. Prior to the

    flood, mankind had become so corrupted that, except
    Noah and those with him, all human inhabitants were
    destroyed. Immediately after the flood the concept of
    nations began, as recorded in Genesis chapter ten. From
    that time on, nations served as a check on each other
    throughout Old Testament history.

    147

    Chapter 12

    U.N. Modern Tower of Babel

    Genesis 11:6

    Divine Providence.